@@ -6,16 +6,16 @@ use {
     crate::{
         app::AppContext,
         errors::ProgramError,
-        verb::PrefixSearchResult,
+        verb::*,
     },
 };
 
 /// an unparsed sequence with its separator (which may be
 /// different from the one provided by local_separator())
-#[derive(Debug)]
+#[derive(Debug, Clone)]
 pub struct Sequence {
-    pub separator: String,
     pub raw: String,
+    pub separator: String,
 }
 
 impl Sequence {
@@ -26,10 +26,10 @@ impl Sequence {
             _ => String::from(";"),
         }
     }
-    pub fn new(separator: String, raw: String) -> Self {
+    pub fn new<S: Into<String>>(raw: S, separator: Option<S>) -> Self {
         Self {
-            separator,
-            raw,
+            raw: raw.into(),
+            separator: separator.map_or_else(Sequence::local_separator, |s| s.into()),
         }
     }
     pub fn new_single(cmd: String) -> Self {
@@ -59,6 +59,12 @@ impl Sequence {
         }
         Ok(commands)
     }
+    pub fn has_selection_group(&self) -> bool {
+        str_has_selection_group(&self.raw)
+    }
+    pub fn has_other_panel_group(&self) -> bool {
+        str_has_other_panel_group(&self.raw)
+    }
 }
 
 /// an input may be made of two parts:
@@ -75,16 +81,14 @@ fn add_commands(
     let raw_parts = CommandParts::from(input.to_string());
     let (pattern, verb_invocation) = raw_parts.split();
     if let Some(pattern) = pattern {
-        debug!("adding pattern: {:?}", pattern);
         commands.push((input.to_string(), Command::from_parts(pattern, false)));
     }
     if let Some(verb_invocation) = verb_invocation {
-        debug!("adding verb_invocation: {:?}", verb_invocation);
         let command = Command::from_parts(verb_invocation, true);
         if let Command::VerbInvocate(invocation) = &command {
             // we check that the verb exists to avoid running a sequence
             // of actions with some missing
-            match con.verb_store.search(&invocation.name) {
+            match con.verb_store.search_prefix(&invocation.name) {
                 PrefixSearchResult::NoMatch => {
                     return Err(ProgramError::UnknownVerb {
                         name: invocation.name.to_string(),
